"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _core = require("@shikijs/core");
var _engineJavascript = require("@shikijs/engine-javascript");
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const FONT_FAMILY = _reactNative.Platform.select({
  ios: 'Menlo',
  android: 'monospace',
  default: 'monospace'
});
const engine = (0, _engineJavascript.createJavaScriptRegexEngine)({
  forgiving: true,
  simulation: true,
  cache: new Map()
});
const SyntaxHighlighter = ({
  text,
  language,
  languageId,
  theme,
  fontSize = 14,
  scrollViewProps,
  textStyle,
  containerStyle
}) => {
  const stylesheet = (0, _react.useMemo)(() => {
    const processedStyles = new Map();
    if (!theme.tokenColors) {
      console.warn('Theme does not contain tokenColors');
      return processedStyles;
    }
    theme.tokenColors.forEach(({
      scope,
      settings
    }) => {
      if (!scope || !settings) return;
      const scopes = Array.isArray(scope) ? scope : [scope];
      scopes.forEach(singleScope => {
        processedStyles.set(singleScope, {
          color: settings.foreground,
          fontStyle: settings.fontStyle
        });
      });
    });
    return processedStyles;
  }, [theme]);
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    let mounted = true;
    async function fetchTokens() {
      if (!text) {
        setTokens([]);
        return;
      }
      try {
        const highlighter = await (0, _core.createHighlighterCore)({
          langs: language ? [language] : [],
          themes: [theme],
          engine
        });
        const result = highlighter.codeToTokens(text, {
          lang: languageId || 'plaintext',
          theme,
          includeExplanation: true
        });
        if (mounted) {
          setTokens(result.tokens || []);
          setError(null);
        }
      } catch (err) {
        console.error('Syntax highlighting failed:', err);
        if (mounted) {
          setError(err instanceof Error ? err : new Error('Highlighting failed'));
          setTokens([[{
            content: text,
            color: '#d8dee9',
            offset: 0
          }]]);
        }
      }
    }
    fetchTokens();
    return () => {
      mounted = false;
    };
  }, [text, language, languageId, theme]);
  const renderTokenLine = (tokens, lineIndex) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: tokens.map((token, tokenIndex) => {
      const firstScope = token.explanation?.[0]?.scopes[0];
      const applicableStyle = firstScope ? stylesheet.get(firstScope.scopeName) : {};
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: [{
          fontFamily: FONT_FAMILY,
          fontSize,
          color: applicableStyle?.color
        }, applicableStyle?.fontStyle === 'italic' ? {
          fontStyle: 'italic'
        } : {}, applicableStyle?.fontStyle === 'bold' ? {
          fontWeight: 'bold'
        } : {}, textStyle || {} // Ensure textStyle is always an object
        ],
        children: token.content
      }, `${lineIndex}-${tokenIndex}`);
    })
  }, lineIndex);
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
      horizontal: true,
      ...scrollViewProps,
      style: [{
        flex: 1,
        minHeight: 20
      }, scrollViewProps?.style],
      contentContainerStyle: [{
        padding: 16
      }, containerStyle],
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: [{
          fontFamily: FONT_FAMILY,
          fontSize
        }, textStyle],
        children: text
      })
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    ...scrollViewProps,
    style: [{
      flex: 1,
      minHeight: 20
    }, scrollViewProps?.style],
    contentContainerStyle: [{
      padding: 16
    }, containerStyle],
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, index) => renderTokenLine(line, index))
    })
  });
};
var _default = exports.default = SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map